<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Unable to access the Rivendell Database!
Please enter a login for an account with
administrative rights on the mySQL server,
and we will try to get this straightened out.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong access permissions for accessing mySQL!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to connect to mySQL!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Create DB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create a Rivendell Database!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to connect to new Rivendell Database!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create Rivendell Database!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to connect to Rivendell Database!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Initialize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to initialize Rivendell Database!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Created Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Rivendell Database Created!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Rivendell Database is too old to be upgraded,
and so must be replaced.  This will DESTROY any
existing audio and data!  If you want to do this,
enter a username and password for a mySQL account
with administrative privledges, otherwise hit cancel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to log into Administrator account!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to authorize a Rivendell Database!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Needed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Rivendell Database needs to be updated.
All audio and settings will be preserved, but
this will STOP any audio playout or recording
on this machine for a few seconds.  Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to update Rivendell Database!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Rivendell Database has
been updated to Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Updated</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddGroup</name>
    <message>
        <source>Add Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Group Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Group for All Users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Group for All Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must give the group a name!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddHostvar</name>
    <message>
        <source>Add Host Variable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variable Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variable Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remark:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddMatrix</name>
    <message>
        <source>Add Switcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Matrix Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local GPIO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generic GPO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generic Serial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local Audio Adapter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logitek vGuest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BroadcastTools SS16.4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StarGuide III</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BroadcastTools SS4.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Switcher Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Matrix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matrix already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Axia LiveWire</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddReport</name>
    <message>
        <source>Add Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Report Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must provide a report name!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A report with that name already exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddStation</name>
    <message>
        <source>Add Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New &amp;Host Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base Host On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Host Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must give the host a name!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddSvc</name>
    <message>
        <source>Add Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Service Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base Service On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Host Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must give the service a name!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddUser</name>
    <message>
        <source>Add User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New User Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must give the user a name!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Already Exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutofillCarts</name>
    <message>
        <source>Autofill Carts - Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditAudioPorts</name>
    <message>
        <source>Edit Audio Ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clock Source:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Analog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES/EBU</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SP/DIFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES/EBU Signal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SP/DIFF Signal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Word Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditBackup</name>
    <message>
        <source>Backup config for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Backups For:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup Directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must supply a backup path!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditDecks</name>
    <message>
        <source>Configure RDCatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monitor Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monitor defaults to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample Rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bit Rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switcher Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switcher Matrix:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switcher Output:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switcher Delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1/10 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trim Threshold:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error RML:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition Deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>32 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>48 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>56 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>64 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>80 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>96 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>112 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>128 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>160 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>192 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Audio Configuration Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel assignments will not be available for this host, as audio resource data
has not yet been generated.  Please start the Rivendell daemons on this host
(by executing, as user &apos;root&apos;,  the command &quot;/etc/init.d/rivendell start&quot;)
in order to populate the audio resources database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEndpoint</name>
    <message>
        <source>Edit Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feed: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine (Hex): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Provider ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device (Hex): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Engine Number is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Provider ID is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Device Number is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Service ID is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGpi</name>
    <message>
        <source>Edit GPI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPI: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Number: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Cart Number!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGroup</name>
    <message>
        <source>Group: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Group Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group &amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Cart &amp;Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Cart Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enforce Cart Range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include this group in Traffic reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include this group in Music reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transmit Now &amp;&amp; Next data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;olor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected cart range conflicts with the following groups:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>
Do you still want to save?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditHostvar</name>
    <message>
        <source>Edit Host Variable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variable Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variable Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remark:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMatrix</name>
    <message>
        <source>Edit Switcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matrix Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switcher Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TCP/IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Card:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP Address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inputs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outputs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPIs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPOs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure
&amp;Inputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure
&amp;Outputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure
&amp;Xpoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure
GP&amp;Is</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vGuest
Switches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vGuest
Displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveWire
Nodes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Primary Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serial Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The primary IP address is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The backup IP address is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The primary and backup connections must be different!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNowNext</name>
    <message>
        <source>Edit Now &amp; Next Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Master Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP Address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UDP Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UDP String:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RML:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The IP address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditRDAirPlay</name>
    <message>
        <source>RDAirPlay config for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel Assignments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start RML:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop RML:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 1 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 2 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition/Cue Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SoundPanel First Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SoundPanel Second Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SoundPanel Third Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SoundPanel Fourth Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SoundPanel Fifth and Later Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Now &amp;&amp; Next
Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual Segue:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>msecs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forced Segue:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pie Counts Last:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>secs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pie Counts To:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Trans. Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host Panels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Panels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flash Active Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Button Pausing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miscellaneous Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Startup Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check TimeSync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Auxlog 1 Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Auxlog 2 Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Cart Search Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Paused Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space Bar Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start/Stop Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>start with empty log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>load previous log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>load specified log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At Startup:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart Log After Unclean Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Audio Configuration Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel assignments will not be available for this host, as audio resource data
has not yet been generated.  Please start the Rivendell daemons on this host
(by executing, as user &apos;root&apos;,  the command &quot;/etc/init.d/rivendell start&quot;)
in order to populate the audio resources database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Segue Length!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Forced Segue Length!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label Template:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditRDLibrary</name>
    <message>
        <source>RDLibrary config for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>INPUT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OUTPUT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Max Record Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;VOX Threshold:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dbFS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;AutoTrim Threshold:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tail Preroll:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ripper Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paranoia Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripper Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;FreeDB Server:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Sample Rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Bitrate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoTrim:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VOX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Audio Configuration Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel assignments will not be available for this host, as audio resource data
has not yet been generated.  Please start the Rivendell daemons on this host
(by executing, as user &apos;root&apos;,  the command &quot;/etc/init.d/rivendell start&quot;)
in order to populate the audio resources database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>32 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>48 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>56 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>64 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>80 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>96 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>112 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>128 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>160 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>192 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>40 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>224 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>256 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>320 kbps/chan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow E&amp;xternal Editing:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditReport</name>
    <message>
        <source>Edit Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Report Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export &amp;Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Station ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Number Parameters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Leading Zeros</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Digits:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Station Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines per Page:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ser&amp;vice Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Station &amp;Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linux Export Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows Export Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Event Types:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Events From:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Only OnAir Events:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Hosts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source Hosts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditStation</name>
    <message>
        <source>Host: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ho&amp;st Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default &amp;User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;IP Address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> mS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Time Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Startup Cart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Heartbeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>secs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RD&amp;Library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDCatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDAirPlay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDPanel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dropboxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio
Resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio
Ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serial
Ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switchers
GPIO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host
Variables</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The specified IP address is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Heartbeat Cart number is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Editor &amp;Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Realtime Filtering</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditSvc</name>
    <message>
        <source>Edit Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Service Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service &amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log &amp;Template Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voicetrack Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert CHAIN TO at log end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AutoRefresh By Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure 
&amp;Autofill Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable &amp;Hosts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic Data Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linux Import Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows Import Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note Cart String:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time - Hours:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time - Minutes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time - Seconds:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length - Hours:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length - Minutes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length - Seconds:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contract #:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annc. Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test 
&amp;Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Data Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert Traffic Break String:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert Voice Track String:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test 
&amp;Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Import Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before testing, the import configuration
must be saved.  Save now?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditSvcPerms</name>
    <message>
        <source>Service: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Hosts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabled Hosts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTtys</name>
    <message>
        <source>Edit TTYs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TTY Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Baud Rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data Bits:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Bits:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Terminator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Even</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Odd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CR/LF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditUser</name>
    <message>
        <source>User: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;User Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Full Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Phone:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change
&amp;Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Administrative Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Administer S&amp;ystem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Production Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Create Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Modify Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit Netcatch Schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Voicetrack Logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create &amp;Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>De&amp;lete Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete &amp;Report Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Modify Template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OnAir Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Playout Logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rearrange Log Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Log &amp;Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Lo&amp;g Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure System Panels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Podcasting Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cre&amp;ate Podcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;dit Podcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dele&amp;te Podcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assign Group
Permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assign Podcast Feed
Permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Web Logins</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditVguestResource</name>
    <message>
        <source>Engine (Hex): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device (Hex): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Surface (Hex): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bus/Relay (Hex): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit vGuest Switch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit vGuest Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Engine Number is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Device Number is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Surface Number is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Bus/Relay Number is Invalid!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <source>System Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Radio Automation System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Schema</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright 2002-2007</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is free software, and comes with ABSOLUTELY NO WARRANTY,
not even the implied warranties of MERCHANTIBILITY or FITNESS FOR A
PARTICULAR PURPOSE.  Touch the &quot;View License&quot; button for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View
&amp;License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListEndpoints</name>
    <message>
        <source>List Inputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List Outputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>INPUT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OUTPUT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ENGINE (Hex)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DEVICE (Hex)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PROVIDER ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SERVICE ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>stereo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListGpis</name>
    <message>
        <source>List GPIs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPI Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MACRO CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[unassigned]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListGroups</name>
    <message>
        <source>Rivendell Group List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate
&amp;Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>START CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>END CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ENFORCE RANGE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DEFAULT TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRAFFIC REPORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MUSIC REPORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NOW &amp; NEXT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Groups:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>member carts will be deleted along with group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListHostvars</name>
    <message>
        <source>Host Variables for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host Variables</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VALUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMARK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListMatrices</name>
    <message>
        <source>Rivendell Switcher List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switchers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MATRIX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete switcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL references to this switcher will be deleted!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting Switcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local GPIO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generic GPO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generic Serial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local Audio Adapter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logitek vGuest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BroadcastTools SS16.4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StarGuide III</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BroadcastTools SS4.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Axia LiveWire</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>Rivendell Report List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>R&amp;eports:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListStations</name>
    <message>
        <source>Rivendell Workstation List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ho&amp;sts:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Station</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListSvcs</name>
    <message>
        <source>Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Services:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>logs owned by this service that will also be deleted.
Do you still want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logs Exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListUsers</name>
    <message>
        <source>Rivendell User List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Users:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Delete User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot delete yourself!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Login</name>
    <message>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User &amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAdmin - Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daemons Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to start Rivendell System Daemons!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insufficient Priviledges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This account has insufficient priviledges for this operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage
&amp;Users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage
&amp;Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage
&amp;Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage
Ho&amp;sts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage
R&amp;eports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System
Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler
Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Backup
Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore
Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell Database Backup (*.sql)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create backup!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup completed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WARNING: This operation will COMPLETELY
OVERWRITE the existing Rivendell Database!
Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to restore backup!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore completed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage
&amp;Feeds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MySqlLogin</name>
    <message>
        <source>mySQL Admin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User &amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameGroup</name>
    <message>
        <source>Rename Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Group Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New &amp;Group Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The group name is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>group already exists.
Do you want to combine the two?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group Exists</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TestImport</name>
    <message>
        <source>Test Traffic Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test Music Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using source file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contract #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Announcement Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error during import
please check your settings and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[spot break]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewAdapters</name>
    <message>
        <source>Audio Resource Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Resources on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SUPPORTED AUDIO DRIVERS
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SUPPORTED IMPORT FORMATS
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>    PCM16 Linear
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>    MPEG Layer 1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>    MPEG Layer 2
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>    MPEG Layer 3
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>    OggVorbis
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SUPPORTED EXPORT FORMATS
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>    Free Lossless Audio Codec (FLAC)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AUDIO ADAPTERS
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not present</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>      Driver: AudioScience HPI
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>      Driver: JACK Audio Connection Kit
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>      Driver: Advanced Linux Sound Architecture (ALSA)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>      Driver: UNKNOWN
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inputs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outputs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NO DATA AVAILABLE

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please start the Rivendell daemons on this host (by executing, as user &apos;root&apos;, the command &quot;/etc/init.d/rivendell start&quot;) in order to populate the audio resources database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
